Package: metafolio
Type: Package
Title: Metapopulation Simulations for Conserving Salmon Through
        Portfolio Optimization
Version: 0.1.2
Authors@R: c(person(given = c("Sean", "C."),
             family = "Anderson",
             role = c("aut", "cre"),
             email = "sean@seananderson.ca",
             comment = c(ORCID = "0000-0001-9563-1937")),
    person(c("Jonathan", "W."), "Moore", role = "ctb"),
    person(c("Michelle", "M."), "McClure", role = "ctb"),
    person(c("Nicholas", "K."), "Dulvy", role = "ctb"),
    person(c("Andrew", "B."), "Cooper", role = "ctb"))
Description: A tool to simulate salmon metapopulations and apply financial
    portfolio optimization concepts. The package accompanies the paper 
    Anderson et al. (2015) <doi:10.1101/2022.03.24.485545>.
License: GPL-2
URL: https://github.com/seananderson/metafolio
BugReports: https://github.com/seananderson/metafolio/issues
VignetteBuilder: knitr
Depends: R (>= 3.5.0)
LinkingTo: Rcpp, RcppArmadillo
Imports: Rcpp (>= 0.11.2), plyr, colorspace, MASS
Suggests: knitr, TeachingDemos, RColorBrewer, reshape2
RoxygenNote: 7.2.3
Encoding: UTF-8
NeedsCompilation: yes
Packaged: 2023-10-20 17:44:53 UTC; seananderson
Author: Sean C. Anderson [aut, cre] (<https://orcid.org/0000-0001-9563-1937>),
  Jonathan W. Moore [ctb],
  Michelle M. McClure [ctb],
  Nicholas K. Dulvy [ctb],
  Andrew B. Cooper [ctb]
Maintainer: Sean C. Anderson <sean@seananderson.ca>
Repository: CRAN
Date/Publication: 2023-10-20 18:10:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 20:19:34 UTC; unix
Archs: metafolio.so.dSYM
