# Generated by roxygen2: do not edit by hand

export(CVaR)
export(VaR)
export(count_quasi_exts)
export(create_asset_weights)
export(fit_ricker)
export(generate_env_ts)
export(generate_straying_matrix)
export(get_port_vals)
export(gg_color_hue)
export(impl_error)
export(meta_sim)
export(monte_carlo_portfolios)
export(plot_cons_plans)
export(plot_correlation_between_returns)
export(plot_efficient_portfolios)
export(plot_rickers)
export(plot_sim_ts)
export(plot_sp_A_ts)
export(ricker)
export(ricker_escapement)
export(ricker_v_t)
export(run_cons_plans)
export(thermal_curve_a)
export(thermal_integration)
importFrom(Rcpp,cppFunction)
importFrom(grDevices,chull)
importFrom(grDevices,contourLines)
importFrom(grDevices,hcl)
importFrom(graphics,abline)
importFrom(graphics,axTicks)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,box)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,matplot)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot.default)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,rect)
importFrom(graphics,text)
importFrom(stats,integrate)
importFrom(stats,lm)
importFrom(stats,na.omit)
importFrom(stats,optimize)
importFrom(stats,quantile)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,uniroot)
importFrom(stats,var)
useDynLib(metafolio, .registration = TRUE)
